def format_accounting(number):
    # 将数字转换为字符串，并去除小数部分
    str_number = str(int(number))

    # 检查数字的正负性
    if number < 0:
        sign = '-'
        str_number = str_number[1:]  # 去除负号
    else:
        sign = ''

    # 添加千位分隔符
    parts = []
    while str_number:
        parts.append(str_number[-3:])
        str_number = str_number[:-3]
    formatted_number = ','.join(reversed(parts))

    # 添加货币符号和负号（如果有）
    formatted_number = f'{sign} {formatted_number}'

    return formatted_number



def find_sum_combinations(arr: [float | int], target: float | int) -> [] | None:
    """
    找出数组中和为目标值的所有组合 ex: [1,3,5] and 8 -> [3,5]
    :param arr: 需要查找的数组
    :param target: 目标值
    :return:
    """

    def find_sum_combinations_base(arr, n, y):
        arr.sort()  # 对数组进行排序，以便按顺序选择元素
        result = []
        current_combination = []
        current_sum = 0
        start_index = 0

        def backtrack(start_index, current_sum):
            nonlocal result, current_combination

            if current_sum == y and len(current_combination) == n:
                result.append(current_combination[:])
                return

            for i in range(start_index, len(arr)):
                if current_sum + arr[i] > y:  # 当前和已经超过目标和，剪枝
                    break

                if len(current_combination) < n:
                    current_combination.append(arr[i])
                    current_sum += arr[i]
                    backtrack(i + 1, current_sum)
                    current_combination.pop()
                    current_sum -= arr[i]

        backtrack(start_index, current_sum)
        return result

    for i in range(1, len(arr)):
        result = find_sum_combinations_base(arr, i, target)
        if result:
            # print(f"找到了{n}个数的和为{y}的组合：")
            for combination in result:
                print(combination)


import os
import subprocess

import requests


class Compresser:
    def __init__(self):
        self.__url = 'https://www.7-zip.org/a/7zr.exe'
        self.__filename = '7z.exe'
        if not os.path.exists(self.__filename):
            response = requests.get(self.__url)
            with open(self.__filename, 'wb') as f:
                f.write(response.content)

    def __run_cmd(self, cmd: str) -> [int, str]:
        """
        执行命令
        :param cmd: 运行的命令
        :return: 状态值和输出
        """
        try:
            # 执行curl命令并捕获输出和错误
            result = subprocess.run(cmd, shell=True, capture_output=True, text=True)
            return [0, str(result.stdout)]
        except subprocess.CalledProcessError as e:
            # 输出错误信息和返回码
            return [int(e.returncode), str(e.output.decode('utf-8'))]

    def yasuo(self, input_file, output_file, password=None) -> [int, str]:
        """
        压缩文件
        :param input_file: 源文件地址
        :param output_file: 压缩文件地址
        :param password: [option] 设置密码
        :return:
        """
        command = f'{self.__filename} a -p{password} {output_file} {input_file}'
        if password:
            command = f'{self.__filename} a -p{password} {output_file} {input_file}'
        else:
            command = f'{self.__filename} a {output_file} {input_file}'
        result = self.__run_cmd(command)
        return result

    def jieya(self, input_file, output_file, password=None) -> [int, str]:
        """
        解压文件
        :param input_file: 源文件地址
        :param output_file: 解压文件目录
        :param password:
        :return:
        """
        command = f'{self.__filename} x -p{password} {input_file} -o{output_file}'
        if password:
            command = f'{self.__filename} x -p{password} {input_file} -o{output_file}'
        else:
            command = f'{self.__filename} x {input_file} -o{output_file}'
        result = self.__run_cmd(command)
        return result



import subprocess


def run_cmd(cmd: str) -> [int, str]:
    """
    执行命令
    :param cmd: 运行的命令
    :return: 状态值和输出
    """
    try:
        # 执行curl命令并捕获输出和错误
        result = subprocess.run(cmd, shell=True, capture_output=True, text=True)
        return [0, str(result.stdout)]
    except subprocess.CalledProcessError as e:
        # 输出错误信息和返回码
        return [e.returncode, str(e.output.decode('utf-8'))]
